OC.L10N.register(
    "dav",
    {
    "Calendar" : "Koledar",
    "Tasks" : "Naloge",
    "Personal" : "Osebno",
    "{actor} created calendar {calendar}" : "{actor} ustvari koledar {calendar}",
    "You created calendar {calendar}" : "Ustvarite koledar {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} izbriše koledar {calendar}",
    "You deleted calendar {calendar}" : "Izbrišete koledar {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} posodobi koledar {calendar}",
    "You updated calendar {calendar}" : "Posodobite koledar {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} obnovi koledar {calendar}",
    "You restored calendar {calendar}" : "Ustvarite koledar {calendar}",
    "You shared calendar {calendar} as public link" : "Omogočite souporabo koledarja {calendar} z javno povezavo",
    "You removed public link for calendar {calendar}" : "Odstranite javno povezavo koledarja {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} mi omogoči souporabo koledarja {calendar}",
    "You shared calendar {calendar} with {user}" : "Omogočite souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} omogoči souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} mi oneomogoči souporabo koledarja {calendar}",
    "You unshared calendar {calendar} from {user}" : "Onemogočite souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} onemogoči souporabo koledarja {calendar} z uporabnikom {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} onemogoči souporabo koledarja {calendar} s samim sabo",
    "You shared calendar {calendar} with group {group}" : "Omogočite souporabo koledarja {calendar} s skupino {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} omogoči souporabo koledarja {calendar} s skupino {group}",
    "You unshared calendar {calendar} from group {group}" : "Onemogočite souporabo koledarja {calendar} s skupino {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} onemogoči souporabo koledarja {calendar} s skupino {group}",
    "Untitled event" : "Neimenovan dogodek¨",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ustvari dogodek {event} v koledarju {calendar}",
    "You created event {event} in calendar {calendar}" : "Ustvarite dogodek {event} v koledarju {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} izbriše dogodek {event} iz koledarja {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Izbrišete dogodek {event} v koledarju {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} posodobi dogodek {event} v koledarju {calendar}",
    "You updated event {event} in calendar {calendar}" : "Posodobite dogodek {event} v koledarju {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} premakne dogodek {event} iz koledarja {sourceCalendar} v koledar {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Premaknete dogodek {event} iz koledarja {sourceCalendar} v koledar {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} obnovi dogodek {event} v koledarju {calendar}",
    "You restored event {event} of calendar {calendar}" : "Obnovite dogodek {event} v koledarju {calendar}",
    "Busy" : "Zasedeno",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} ustvari nalogo {todo} v koledarju {calendar}",
    "You created to-do {todo} in list {calendar}" : "Ustvarite nalogo {todo} v koledarju {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} izbriše nalogo {todo} iz koledarja {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Izbrišete nalogo {todo} iz koledarja {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} posodobi nalogo {todo} v koledarju {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Posodobite nalogo {todo} v seznamu {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} razreši nalogo {todo} v koledarju {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Razrešite nalogo {todo} v seznamu {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} ponovno odpre nalogo {todo} v koledarju {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Ponovno odprete nalogo {todo} v seznamu {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} premakne nalogo {todo} iz seznama koledarja {sourceCalendar} v koledar {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Premaknete nalogo {todo} iz seznama koledarja {sourceCalendar} v koledar {targetCalendar}",
    "Calendar, contacts and tasks" : "Koledar, stiki in naloge",
    "A <strong>calendar</strong> was modified" : "V <strong>koledar</strong> je vpisana sprememba",
    "A calendar <strong>event</strong> was modified" : "Spremenjen je <strong>dogodek</strong> v koledarju",
    "A calendar <strong>to-do</strong> was modified" : "Spremenjena je <strong>naloga</strong> koledarja",
    "Contact birthdays" : "Obletnice stikov",
    "Death of %s" : "%s (obletnica smrti)",
    "Untitled calendar" : "Neimenovan koledar",
    "Calendar:" : "Koledar:",
    "Date:" : "Datum:",
    "Where:" : "Kje:",
    "Description:" : "Opis:",
    "_%n year_::_%n years_" : ["%n leto","%n leti","%n leta","%n let"],
    "_%n month_::_%n months_" : ["%n mesec","%n meseca","%n meseci","%n mesecev"],
    "_%n day_::_%n days_" : ["%n dan","%n dneva","%n dni","%n dni"],
    "_%n hour_::_%n hours_" : ["%n ura","%n uri","%n ure","%n ur"],
    "_%n minute_::_%n minutes_" : ["%n minuta","%n minuti","%n minute","%n minut"],
    "%s (in %s)" : "%s (čez %s)",
    "%s (%s ago)" : "%s (%s nazaj)",
    "Calendar: %s" : "Koledar: %s",
    "Date: %s" : "Datum: %s",
    "Description: %s" : "Opis: %s",
    "Where: %s" : "Kje: %s",
    "%1$s via %2$s" : "%1$s prek %2$s",
    "Cancelled: %1$s" : "Preklicano: %1$s",
    "\"%1$s\" has been canceled" : "Dogodek »%1$s« je preklican",
    "Re: %1$s" : "Odg: %1$s",
    "%1$s has accepted your invitation" : "%1$ssprejme vaše povabilo",
    "%1$s has tentatively accepted your invitation" : "%1$s pogojno sprejme vabilo",
    "%1$s has declined your invitation" : "%1$s zavrne vaše povabilo.",
    "%1$s has responded to your invitation" : "%1$s pošlje odziv na vaše povabilo.",
    "Invitation updated: %1$s" : "Povabilo je posodobljeno: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s posodobi dogodek »%2$s«",
    "Invitation: %1$s" : "Povabilo: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s vas želi povabiti na »%2$s«",
    "Organizer:" : "Organizator:",
    "Attendees:" : "Udeleženci:",
    "Title:" : "Naslov:",
    "When:" : "Kdaj:",
    "Location:" : "Mesto:",
    "Link:" : "Povezava:",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "More options …" : "Več možnosti ...",
    "More options at %s" : "Več možnosti je na %s",
    "Monday" : "ponedeljek",
    "Tuesday" : "torek",
    "Wednesday" : "sreda",
    "Thursday" : "četrtek",
    "Friday" : "petek",
    "Saturday" : "sobota",
    "Sunday" : "nedelja",
    "January" : "januar",
    "February" : "februar",
    "March" : "marec",
    "April" : "april",
    "May" : "maj",
    "June" : "junij",
    "July" : "julij",
    "August" : "avgust",
    "September" : "september",
    "October" : "oktober",
    "November" : "november",
    "December" : "december",
    "First" : "Prvi",
    "Last" : "Zadnji",
    "Contacts" : "Stiki",
    "{actor} created address book {addressbook}" : "{actor} ustvari imenik {addressbook}",
    "You created address book {addressbook}" : "Ustvarite imenik {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} izbriše imenik {addressbook}",
    "You deleted address book {addressbook}" : "Izbrišete imenik {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} posodobi imenik {addressbook}",
    "You updated address book {addressbook}" : "Posodobite imenik {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} vam omogoči souporabo imenika {addressbook}",
    "You shared address book {addressbook} with {user}" : "Omogočite souporabo imenika {addressbook} z uporabnikom {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} omogoči souporabo imenika {addressbook} z uporabnikom {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} vam onemogoči souporabo imenika {addressbook}",
    "You unshared address book {addressbook} from {user}" : "Onemogočite souporabo imenika {addressbook} z uporabnikom {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} onemogoči souporabo imenika {addressbook} z uporabnikom {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} si je onemogočil souporabo imenika {addressbook}",
    "You shared address book {addressbook} with group {group}" : "Omogočili ste souporabo imenika {addressbook} z vašo skupino {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} je omogočil souporabo imenika {addressbook} z vašo skupino {group}",
    "You unshared address book {addressbook} from group {group}" : "Onemogočili ste souporabo imenika {addressbook} z vašo skupino {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} je onemogočil souporabo imenika {addressbook} s skupino {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} je dadal nov stik {card} v imenik {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Dodali ste nov stik {card} v imenik {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} je izbrisal stik {card} iz imenika {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Odstranili ste stik {card} iz imenika {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} je posodobil stik {card} v imeniku {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Posodobili ste stik {card} v imeniku {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Spremenjen je bil <strong>stik</strong> oziroma <strong>imenik</strong>",
    "Accounts" : "Računi",
    "System address book which holds all accounts" : "Sistemski imenik, ki združuje vse račune",
    "File is not updatable: %1$s" : "Datoteke ni mogoče posodobiti: %1$s",
    "Could not write to final file, canceled by hook" : "Ni bilo mogoče pisati v končno datoteko. Opravilo je bilo preklicano.",
    "Could not write file contents" : "Ni mogoče zapisati vsebine datoteke",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Prišlo je do napake med kopiranjem datoteke na ciljno mesto (kopirano: %1$s, pričakovana velikost pa je: %2$s)",
    "Could not rename part file to final file, canceled by hook" : "Ni mogoče preimenovati delne datoteke v končno ime. Opravilo je bilo preklicano.",
    "Could not rename part file to final file" : "Ni mogoče preimenovati delne datoteke v končno ime.",
    "Failed to check file size: %1$s" : "Preverjanje velikosti je spodletelo: %1$s",
    "Encryption not ready: %1$s" : "Šifriranje ni mogoče: %1$s",
    "Failed to open file: %1$s" : "Odpiranje datoteke je spodletelo: %1$s",
    "Failed to unlink: %1$s" : "Odstranjevanje povezave je spodletelo: %1$s",
    "Failed to write file contents: %1$s" : "Zapisovanje vsebine datoteke je spodletelo: %1$s",
    "File not found: %1$s" : "Datoteke ni mogoče najti: %1$s",
    "System is in maintenance mode." : "Sistem je v vzdrževalnem načinu.",
    "Upgrade needed" : "Zahtevana je posodobitev",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Za uporabo CalDAV in CardDAV v okoljih iOS/macOS je treba %s nastaviti za uporabo HTTPS.",
    "Configures a CalDAV account" : "Nastavi račun CalDAV",
    "Configures a CardDAV account" : "Nastavi račun CardDAV",
    "Events" : "Dogodki",
    "Untitled task" : "Neimenovana naloga",
    "Completed on %s" : "Končana %s",
    "Due on %s by %s" : "Poteče %s ob %s",
    "Due on %s" : "Poteče %s",
    "DAV system address book" : "Imenik sistema DAV",
    "No outstanding DAV system address book sync." : "Usklajevanje DAV ni omogočeno.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Usklajevanje imenika DAV še ni bilo izvedeno, ker je na strežniku več kot 1000 uporabnikov, ali pa je morda prišlo do napake. Možnost je treba zagnati ročnoz ukazom »occ dav:sync-system-addressbook«.",
    "WebDAV endpoint" : "Končna točka WebDAV",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Spletni stražnik še ni ustrezno nastavljen in ne omogoča usklajevanja, kaže, da je vmesnik WebDAV okvarjen.",
    "Migrated calendar (%1$s)" : "Prenesen koledar (%1$s)",
    "Calendars including events, details and attendees" : "Koledarji z dogodki, podrobnostmi in udeleženci",
    "Contacts and groups" : "Stiki in skupine",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Odsotnost je shranjena",
    "Failed to save your absence settings" : "Shranjevanje nastavitev odsotnosti je spodletelo",
    "Absence cleared" : "Odsotnos je preklicana",
    "Failed to clear your absence settings" : "Počiščenje nastavitev odsotnosti je spodletelo",
    "First day" : "Prvi dan",
    "Last day (inclusive)" : "Zadnji dan (vključujoče)",
    "Name of the replacement" : "Ime zamenjave",
    "Short absence status" : "Stanje kratke odsotnosti",
    "Long absence Message" : "Sporočilo dolge odsostnosti",
    "Save" : "Shrani",
    "Disable absence" : "Onemogoči odsostnost",
    "Failed to load availability" : "Nalaganje seznama razpoložljivih polj je spodletelo",
    "Saved availability" : "Čas razpoložljivosti je shranjen",
    "Failed to save availability" : "Shranjevanje časa razpoložljivosti je spodletelo",
    "to" : "do",
    "Delete slot" : "Izbriši možnost",
    "No working hours set" : "Ni navedenih delovnih ur",
    "Add slot" : "Dodaj možnost",
    "Weekdays" : "Delovni dnevi",
    "Pick a start time for {dayName}" : "Izbor časa začetka za {dayName}",
    "Pick a end time for {dayName}" : "Izbor časa konca za {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Samodejno nastavi stanje uporabnika na »Ne moti« in zavračaj prikaz obvestil izven časa razpoložljivosti.",
    "Cancel" : "Prekliči",
    "Import" : "Uvozi",
    "Error while saving settings" : "Prišlo je do napake med shranjevanjem nastavitev",
    "Reset to default" : "Ponastavi na privzeto",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Namestite tudi {calendarappstoreopen}Koledar{linkclose}, ali pa se povežite z {calendardocopen}namiznim oziroma mobilnim usklajevalnikom ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Prepričajte se, da je {emailopen}poštni strežnik{linkclose} pravilno nastavljen.",
    "Calendar server" : "Strežnik koledarja",
    "Send invitations to attendees" : "Pošlji povabilo udeležencem",
    "Automatically generate a birthday calendar" : "Samodejno ustvari koledar rojstnih dni",
    "Birthday calendars will be generated by a background job." : "Koledarji rojstnih dni bodo ustvarjeni in posodabljani v ozadju.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "To pomeni, da ne bodo na voljo takoj po omogočanju, ampak šele po krajšem času.",
    "Send notifications for events" : "Pošlji obvestila za dogodke",
    "Notifications are sent via background jobs, so these must occur often enough." : "Obvestila so poslana samodejno z opravili v ozadju, ker pomeni, da se morajo ta izvajati dovolj pogosto.",
    "Send reminder notifications to calendar sharees as well" : "Pošiljanje opomnikov tudi naročnikom koledarja.",
    "Reminders are always sent to organizers and attendees." : "Opomniki bodo vedno poslani organizatorjem in udeležencem.",
    "Enable notifications for events via push" : "Omogoči potisna obvestila za dogodke",
    "Availability" : "Razpoložljivost",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Če nastavite delovni čas, bodo drugi uporabniki pri izbiri časa sestanka videli, kdaj ste zasedeni.",
    "Absence" : "Odsotnost",
    "Configure your next absence period." : "Nastavitev naslednjega časa odsotnosti",
    "There was an error updating your attendance status." : "Prišlo je do napake med posodabljanjem vaše udeležbe.",
    "Please contact the organizer directly." : "Z organizatorjem stopite neposredno v stik.",
    "Are you accepting the invitation?" : "Ali želite sprejeti povabilo?",
    "Tentative" : "Začasno",
    "Your attendance was updated successfully." : "Vaša prisotnost je uspešno posodobljena.",
    "No results." : "Ni zadetkov",
    "Start typing." : "Začnite vpisovati.",
    "Time zone:" : "Časovni pas:"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
